#
# spec file for package ghc-graphviz
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name graphviz
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2999.18.1.2
Release:        3.1
Summary:        Bindings to Graphviz for graph visualisation
License:        BSD-3-Clause
Group:          System/Libraries
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-colour-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-dlist-devel
BuildRequires:  ghc-fgl-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-polyparse-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-wl-pprint-text-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-fgl-arbitrary-devel
%endif

%description
This library provides bindings for the Dot language used by the Graphviz
(<http://graphviz.org/>) suite of programs for visualising graphs, as well as
functions to call those programs.

Main features of the graphviz library include:

* Almost complete coverage of all Graphviz attributes and syntax.

* Support for specifying clusters.

* The ability to use a custom node type.

* Functions for running a Graphviz layout tool with all specified output types.

* The ability to not only generate but also parse Dot code with two options:
strict and liberal (in terms of ordering of statements).

* Functions to convert FGL graphs and other graph-like data structures to Dot
code - including support to group them into clusters - with a high degree of
customisation by specifying which attributes to use and limited support for the
inverse operation.

* Round-trip support for passing an FGL graph through Graphviz to augment node
and edge labels with positional information, etc.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build


%install
%ghc_lib_install


%check
%cabal_test


%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE.md

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc Changelog.md README.md TODO.md

%changelog
* Fri Jul 22 2016 psimons@suse.com
- Update to version 2999.18.1.2 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2999.18.1.0 revision 0 with cabal2obs.
* Mon May 16 2016 mimi.vx@gmail.com
- update to 2999.18.1.0
  * Monadic graphs can now have edges to and from lists of nodes
  * Compatible with GHC-8.* pre-releases
* Sat Feb 13 2016 mimi.vx@gmail.com
- ghc-graphviz generated by st2obs scritpt
